#' Height and gender of 2000 persons in an artificial population
#' 
#' @name htpop
#' @docType data
#' @format \describe{
#'   \item{height}{height of person, cm}
#'   \item{gender}{factor with levels \code{F} (female) and \code{M} (male)}
#' }
#' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. 230--234 and
#'   441.
"htpop"